(self["webpackJsonp"] = self["webpackJsonp"] || []).push([["legacy-support"],{

/***/ "./src/util/legacy-support.js":
/*!************************************!*\
  !*** ./src/util/legacy-support.js ***!
  \************************************/
/*! no exports provided */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _polymer_polymer_polymer_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @polymer/polymer/polymer-element */ "./node_modules/@polymer/polymer/polymer-element.js");
/* harmony import */ var _polymer_polymer_polymer_legacy__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @polymer/polymer/polymer-legacy */ "./node_modules/@polymer/polymer/polymer-legacy.js");
/* harmony import */ var _polymer_polymer_lib_utils_html_tag__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! @polymer/polymer/lib/utils/html-tag */ "./node_modules/@polymer/polymer/lib/utils/html-tag.js");
/**
 * Provide legacy support to HTML imports by exposing Polymer and
 * Polymer.Element on the window object.
 */



_polymer_polymer_polymer_legacy__WEBPACK_IMPORTED_MODULE_1__["Polymer"].Element = _polymer_polymer_polymer_element__WEBPACK_IMPORTED_MODULE_0__["PolymerElement"];
_polymer_polymer_polymer_legacy__WEBPACK_IMPORTED_MODULE_1__["Polymer"].html = _polymer_polymer_lib_utils_html_tag__WEBPACK_IMPORTED_MODULE_2__["html"];
window.Polymer = _polymer_polymer_polymer_legacy__WEBPACK_IMPORTED_MODULE_1__["Polymer"];

/***/ })

}]);
//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoibGVnYWN5LXN1cHBvcnQuY2h1bmsuanMiLCJzb3VyY2VzIjpbIndlYnBhY2s6Ly8vLi9zcmMvdXRpbC9sZWdhY3ktc3VwcG9ydC5qcyJdLCJzb3VyY2VzQ29udGVudCI6WyIvKipcbiAqIFByb3ZpZGUgbGVnYWN5IHN1cHBvcnQgdG8gSFRNTCBpbXBvcnRzIGJ5IGV4cG9zaW5nIFBvbHltZXIgYW5kXG4gKiBQb2x5bWVyLkVsZW1lbnQgb24gdGhlIHdpbmRvdyBvYmplY3QuXG4gKi9cbmltcG9ydCB7IFBvbHltZXJFbGVtZW50IH0gZnJvbSBcIkBwb2x5bWVyL3BvbHltZXIvcG9seW1lci1lbGVtZW50XCI7XG5pbXBvcnQgeyBQb2x5bWVyIH0gZnJvbSBcIkBwb2x5bWVyL3BvbHltZXIvcG9seW1lci1sZWdhY3lcIjtcbmltcG9ydCB7IGh0bWwgfSBmcm9tIFwiQHBvbHltZXIvcG9seW1lci9saWIvdXRpbHMvaHRtbC10YWdcIjtcblxuUG9seW1lci5FbGVtZW50ID0gUG9seW1lckVsZW1lbnQ7XG5Qb2x5bWVyLmh0bWwgPSBodG1sO1xud2luZG93LlBvbHltZXIgPSBQb2x5bWVyO1xuIl0sIm1hcHBpbmdzIjoiOzs7Ozs7Ozs7O0FBQUE7QUFBQTtBQUFBO0FBQUE7QUFBQTs7OztBQUlBO0FBQ0E7QUFDQTtBQUVBO0FBQ0E7QUFDQTs7OztBIiwic291cmNlUm9vdCI6IiJ9